
# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from eis.claim.api.claim_partner_roles_api import ClaimPartnerRolesApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from eis.claim.api.claim_partner_roles_api import ClaimPartnerRolesApi
from eis.claim.api.claim_partners_api import ClaimPartnersApi
from eis.claim.api.claim_regulations_api import ClaimRegulationsApi
from eis.claim.api.claim_statuses_api import ClaimStatusesApi
from eis.claim.api.claims_api import ClaimsApi
from eis.claim.api.health_check_api import HealthCheckApi
from eis.claim.api.settlements_api import SettlementsApi



"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.claim
from eis.claim.api.claims_api import ClaimsApi  # noqa: E501


class TestClaimsApi(unittest.TestCase):
    """ClaimsApi unit test stubs"""

    def setUp(self):
        self.api = ClaimsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_claim(self):
        """Test case for create_claim

        Create the claim  # noqa: E501
        """
        pass

    def test_delete_claim(self):
        """Test case for delete_claim

        Delete the claim  # noqa: E501
        """
        pass

    def test_get_claim(self):
        """Test case for get_claim

        Retrieve the claim  # noqa: E501
        """
        pass

    def test_get_claim_regulation_summary(self):
        """Test case for get_claim_regulation_summary

        Retrieve the claim regulation summary  # noqa: E501
        """
        pass

    def test_list_claims(self):
        """Test case for list_claims

        List claims  # noqa: E501
        """
        pass

    def test_patch_claim(self):
        """Test case for patch_claim

        Patch the claim  # noqa: E501
        """
        pass

    def test_update_claim(self):
        """Test case for update_claim

        Update the claim  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.claim
from eis.claim.api.claim_statuses_api import ClaimStatusesApi  # noqa: E501


class TestClaimStatusesApi(unittest.TestCase):
    """ClaimStatusesApi unit test stubs"""

    def setUp(self):
        self.api = ClaimStatusesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_claim_status(self):
        """Test case for create_claim_status

        Create the claim status  # noqa: E501
        """
        pass

    def test_delete_claim_status(self):
        """Test case for delete_claim_status

        Delete the claim status  # noqa: E501
        """
        pass

    def test_get_claim_status(self):
        """Test case for get_claim_status

        Retrieve the claim status  # noqa: E501
        """
        pass

    def test_list_claim_statuses(self):
        """Test case for list_claim_statuses

        List claim statuses  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
